@@ -16,13 +16,14 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include <unistd.h>
 
 #include <gst/check/gstcheck.h>
+#include <gst/video/video-info.h>
 
 /* For ease of programming we use globals to keep refs for our floating
  * src and sink pads we create; otherwise we always have to do get_pad,
@@ -32,7 +33,7 @@ static GstPad *mysrcpad, *mysinkpad;
 /* mpeg2 video created with gst-launch-0.10 videotestsrc num-buffers=32 pattern=blue ! "video/x-raw,format=(string)I420,width=176,height=144,framerate=(fraction)25/1" ! ffenc_mpeg2video ! filesink location=test.mpg
 */
 
-guint8 test_stream1[] = {
+static const guint8 test_stream1[] = {
   0x00, 0x00, 0x01, 0xb3, 0x0b, 0x00, 0x90, 0x13,
   0xff, 0xff, 0xe0, 0x28, 0x00, 0x00, 0x01, 0xb5,
   0x14, 0x8a, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00,
@@ -548,7 +549,7 @@ guint8 test_stream1[] = {
   0x09, 0x12, 0x70, 0xb3, 0x80,
 };
 
-guint test_stream_sizes[] = {
+static const guint test_stream_sizes[] = {
   497, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90,
   497, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90, 90,
   497, 90
@@ -557,7 +558,7 @@ guint test_stream_sizes[] = {
 /* mpeg2 video created with gst-launch-0.10 videotestsrc num-buffers=32 pattern=blue ! "video/x-raw,format=(string)I420,width=183,height=217,framerate=(fraction)25/1" ! ffenc_mpeg2video ! filesink location=test.mpg
 */
 
-guint8 test_stream2[] = {
+static const guint8 test_stream2[] = {
   0x00, 0x00, 0x01, 0xb3, 0x0b, 0x70, 0xd9, 0x13,
   0xff, 0xff, 0xe0, 0x28, 0x00, 0x00, 0x01, 0xb5,
   0x14, 0x8a, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00,
@@ -1688,7 +1689,7 @@ guint8 test_stream2[] = {
   0xa5, 0xfb, 0x85, 0xe6, 0xc0
 };
 
-guint test_stream2_sizes[] = {
+static const guint test_stream2_sizes[] = {
   803, 228, 228, 228, 228, 228, 228, 228, 228, 228, 228, 228, 228, 228, 228,
   803, 228, 228, 228, 228, 228, 228, 228, 228, 228, 228, 228, 228, 228, 228,
   803, 228
@@ -1710,17 +1711,23 @@ GstElement *
 setup_mpeg2dec ()
 {
   GstElement *mpeg2dec;
-  GstSegment seg;
+  GstCaps *caps;
 
   GST_DEBUG ("setup_mpeg2dec");
-  mpeg2dec = gst_check_setup_element ("mpeg2dec");
+
+  // Suppress deprecation warning
+  ASSERT_WARNING (mpeg2dec = gst_check_setup_element ("mpeg2dec"));
+
   mysrcpad = gst_check_setup_src_pad (mpeg2dec, &srctemplate);
   mysinkpad = gst_check_setup_sink_pad (mpeg2dec, &sinktemplate);
   gst_pad_set_active (mysrcpad, TRUE);
   gst_pad_set_active (mysinkpad, TRUE);
 
-  gst_segment_init (&seg, GST_FORMAT_TIME);
-  gst_pad_push_event (mysrcpad, gst_event_new_segment (&seg));
+  caps = gst_caps_new_simple ("video/mpeg",
+      "systemstream", G_TYPE_BOOLEAN, FALSE,
+      "mpegversion", G_TYPE_INT, 2, NULL);
+  gst_check_setup_events (mysrcpad, mpeg2dec, caps, GST_FORMAT_TIME);
+  gst_caps_unref (caps);
 
   return mpeg2dec;
 }
@@ -1746,6 +1753,7 @@ GST_START_TEST (test_decode_stream1)
   int i, num_buffers;
   GstCaps *out_caps, *caps;
   guint offset = 0;
+  GstVideoInfo info;
 
   mpeg2dec = setup_mpeg2dec ();
 
@@ -1759,8 +1767,8 @@ GST_START_TEST (test_decode_stream1)
   for (i = 0; i < G_N_ELEMENTS (test_stream_sizes); i++) {
     inbuffer =
         gst_buffer_new_wrapped_full (GST_MEMORY_FLAG_READONLY,
-        test_stream1 + offset, test_stream_sizes[i], 0, test_stream_sizes[i],
-        NULL, NULL);
+        (guint8 *) test_stream1 + offset, test_stream_sizes[i], 0,
+        test_stream_sizes[i], NULL, NULL);
     offset += test_stream_sizes[i];
     ASSERT_BUFFER_REFCOUNT (inbuffer, "inbuffer", 1);
     gst_buffer_ref (inbuffer);
@@ -1776,13 +1784,18 @@ GST_START_TEST (test_decode_stream1)
   fail_unless_equals_int (num_buffers, 30);
 
   /* each buffer should have these caps */
-  out_caps =
-      gst_caps_new_simple ("video/x-raw", "format", G_TYPE_STRING,
-      "I420", "width", G_TYPE_INT, 176, "height", G_TYPE_INT, 144,
-      "pixel-aspect-ratio", GST_TYPE_FRACTION, 1, 1, "framerate",
-      GST_TYPE_FRACTION, 25, 1, "interlace-mode", G_TYPE_STRING, "progressive",
-      "chroma-site", G_TYPE_STRING, "mpeg2",
-      "colorimetry", G_TYPE_STRING, "bt601", NULL);
+  gst_video_info_init (&info);
+  gst_video_info_set_format (&info, GST_VIDEO_FORMAT_I420, 176, 144);
+  GST_VIDEO_INFO_PAR_N (&info) = GST_VIDEO_INFO_PAR_D (&info) = 1;
+  GST_VIDEO_INFO_FPS_N (&info) = 25;
+  GST_VIDEO_INFO_FPS_D (&info) = 1;
+  GST_VIDEO_INFO_FPS_D (&info) = 1;
+  GST_VIDEO_INFO_CHROMA_SITE (&info) = GST_VIDEO_CHROMA_SITE_MPEG2;
+  gst_video_colorimetry_from_string (&GST_VIDEO_INFO_COLORIMETRY (&info),
+      "2:0:0:0");
+  GST_VIDEO_INFO_MULTIVIEW_MODE (&info) = GST_VIDEO_MULTIVIEW_MODE_MONO;
+
+  out_caps = gst_video_info_to_caps (&info);
 
   caps = gst_pad_get_current_caps (mysinkpad);
   GST_LOG ("output caps %" GST_PTR_FORMAT, caps);
@@ -1822,6 +1835,7 @@ GST_START_TEST (test_decode_stream2)
   GstCaps *out_caps;
   GstCaps *caps;
   guint offset = 0;
+  GstVideoInfo info;
 
   mpeg2dec = setup_mpeg2dec ();
 
@@ -1835,8 +1849,8 @@ GST_START_TEST (test_decode_stream2)
   for (i = 0; i < G_N_ELEMENTS (test_stream2_sizes); i++) {
     inbuffer =
         gst_buffer_new_wrapped_full (GST_MEMORY_FLAG_READONLY,
-        test_stream2 + offset, test_stream2_sizes[i], 0, test_stream2_sizes[i],
-        NULL, NULL);
+        (guint8 *) test_stream2 + offset, test_stream2_sizes[i], 0,
+        test_stream2_sizes[i], NULL, NULL);
     offset += test_stream2_sizes[i];
     ASSERT_BUFFER_REFCOUNT (inbuffer, "inbuffer", 1);
     gst_buffer_ref (inbuffer);
@@ -1853,13 +1867,18 @@ GST_START_TEST (test_decode_stream2)
   fail_unless_equals_int (num_buffers, 30);
 
   /* each buffer should have these caps */
-  out_caps =
-      gst_caps_new_simple ("video/x-raw", "format", G_TYPE_STRING, "I420",
-      "width", G_TYPE_INT, 183, "height", G_TYPE_INT, 217,
-      "pixel-aspect-ratio", GST_TYPE_FRACTION, 1, 1, "framerate",
-      GST_TYPE_FRACTION, 25, 1, "interlace-mode", G_TYPE_STRING, "progressive",
-      "chroma-site", G_TYPE_STRING, "mpeg2", "colorimetry", G_TYPE_STRING,
-      "bt601", NULL);
+  gst_video_info_init (&info);
+  gst_video_info_set_format (&info, GST_VIDEO_FORMAT_I420, 183, 217);
+  GST_VIDEO_INFO_PAR_N (&info) = GST_VIDEO_INFO_PAR_D (&info) = 1;
+  GST_VIDEO_INFO_FPS_N (&info) = 25;
+  GST_VIDEO_INFO_FPS_D (&info) = 1;
+  GST_VIDEO_INFO_FPS_D (&info) = 1;
+  GST_VIDEO_INFO_CHROMA_SITE (&info) = GST_VIDEO_CHROMA_SITE_MPEG2;
+  gst_video_colorimetry_from_string (&GST_VIDEO_INFO_COLORIMETRY (&info),
+      "2:0:0:0");
+  GST_VIDEO_INFO_MULTIVIEW_MODE (&info) = GST_VIDEO_MULTIVIEW_MODE_MONO;
+
+  out_caps = gst_video_info_to_caps (&info);
 
   caps = gst_pad_get_current_caps (mysinkpad);
   GST_LOG ("output caps %" GST_PTR_FORMAT, caps);
@@ -1952,19 +1971,4 @@ mpeg2dec_suite (void)
   return s;
 }
 
-int
-main (int argc, char **argv)
-{
-  int nf;
-
-  Suite *s = mpeg2dec_suite ();
-  SRunner *sr = srunner_create (s);
-
-  gst_check_init (&argc, &argv);
-
-  srunner_run_all (sr, CK_NORMAL);
-  nf = srunner_ntests_failed (sr);
-  srunner_free (sr);
-
-  return nf;
-}
+GST_CHECK_MAIN (mpeg2dec);
